``edist``
=========

.. module:: upoints.edist
   :synopsis: Simple command line coordinate processing

.. autoclass:: LocationsError
.. autoclass:: NumberedPoint
.. autoclass:: NumberedPoints

.. autofunction:: read_locations
.. autofunction:: read_csv
.. autofunction:: main
